@@ -239,7 +239,7 @@ sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info, $sup
     push @load_extra, "max=$max" if defined $max;
 
     if ($value_type eq 'integer' and $desc =~ /defaults? (?:to|is) (\d+)/i) {
-        push @load_extra, "default=$1" ;
+        push @load_extra, "upstream_default=$1" ;
     }
 
     if ($supersedes) {
@@ -303,7 +303,7 @@ foreach my $config_class (keys $data->{class}->%*) {
         qq!copyright:0="2010-2016 Lennart Poettering and others"!,
         qq!copyright:1="2016 Dominique Dumont"!,
         qq!license="LGPLv2.1+"!,
-        qq!accept:".*" type=leaf value_type=uniline!,
+        qq!accept:".*" type=leaf value_type=uniline warn="Unknown parameter"!,
     ]);
 
 }
