@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Unit ;
-$Config::Model::Backend::Systemd::Unit::VERSION = '0.232.2';
+$Config::Model::Backend::Systemd::Unit::VERSION = '0.232.3';
 use strict;
 use warnings;
 use 5.010;
@@ -87,11 +87,23 @@ sub load_data {
     my $self = shift;
     my %args = @_ ; # data, check, split_reg
 
+    my $check = $args{check};
     my $data = $args{data} ;
+
     # use ObjTreeScanner ?
     my $disp_leaf = sub {
         my ($scanner, $data, $node,$element_name,$index, $leaf_object) = @_ ;
-        $leaf_object->store($data);
+        if (ref($data) eq 'ARRAY') {
+            Config::Model::Exception::User->throw(
+                object => $leaf_object,
+                error  => "Cannot store twice the same value ('"
+                .join("', '",@$data). "'). "
+                ."Is '$element_name' line duplicated in config file ? "
+                ."You can use -force option to load value '". $data->[-1]."'."
+            ) if $check eq 'yes';
+            $data = $data->[-1];
+        }
+        $leaf_object->store(value =>  $data, check => $check);
     } ;
 
     my $unit_cb = sub {
@@ -108,7 +120,7 @@ sub load_data {
             my $unit_data = $data_ref->{$elt}; # extract relevant data
 
             # force creation of element (can be removed with Config::Model 2.086)
-            my $obj = $node->fetch_element($elt);
+            my $obj = $node->fetch_element(name => $elt, check => $check);
 
             $scanner->scan_element($unit_data, $node,$elt) ;
         }
@@ -122,14 +134,9 @@ sub load_data {
     my $list_cb = sub {
         my ($scanner, $data,$node,$element_name,@idx) = @_ ;
         my $list_ref = ref($data) ? $data : [ $data ];
-        my $list_obj= $node->fetch_element($element_name);
+        my $list_obj= $node->fetch_element(name => $element_name, check => $check);
         foreach my $d (@$list_ref) {
-            #if (length $d) {
             $list_obj->push($d); # push also empty values
-            #}
-            #else {
-            #    $list_obj->clear;
-            #}
         }
 
     };
@@ -198,7 +205,7 @@ Config::Model::Backend::Systemd::Unit - R/W backend for systemd unit files
 
 =head1 VERSION
 
-version 0.232.2
+version 0.232.3
 
 =head1 SYNOPSIS
 
